@@ -1,8 +1,7 @@
-use std::path::Path;
-
-use anyhow::Context;
-
 use crate::Result;
+use anyhow::Context;
+use std::path::Path;
+use tracing::debug;
 
 const COMPRESSION_LEVEL: u32 = 2;
 
@@ -11,16 +10,26 @@ pub struct WasmBindgenOutput {
     pub compressed_wasm: Vec<u8>,
 }
 pub fn generate(wasm_file: &Path) -> Result<WasmBindgenOutput> {
+    debug!("running wasm-bindgen...");
+    let start = std::time::Instant::now();
     let mut output = wasm_bindgen_cli_support::Bindgen::new()
         .input_path(wasm_file)
         .web(true)?
         .typescript(false)
         .generate_output()?;
+    debug!("finished wasm-bindgen (took {:?})", start.elapsed());
 
     let js = output.js().to_owned();
-    let wasm = output.wasm_mut().emit_wasm();
 
+    debug!("emitting wasm...");
+    let start = std::time::Instant::now();
+    let wasm = output.wasm_mut().emit_wasm();
+    debug!("emitting wasm took {:?}", start.elapsed());
+
+    debug!("compressing wasm...");
+    let start = std::time::Instant::now();
     let compressed_wasm = compress(&wasm).context("failed to compress wasm file")?;
+    debug!("compressing took {:?}", start.elapsed());
 
     Ok(WasmBindgenOutput { js, compressed_wasm })
 }
